
#line 3 "scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 36
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 123
#define YY_END_OF_BUFFER 124
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[779] =
    {   0,
      124,  122,  123,    3,  122,  123,    1,  123,   36,  122,
      123,  122,  123,   11,  122,  123,   31,  122,  123,   33,
      122,  123,  122,  123,   20,  122,  123,   21,  122,  123,
       29,  122,  123,   27,  122,  123,   60,  122,  123,   28,
      122,  123,   26,  122,  123,   30,  122,  123,  115,  122,
      123,  115,  122,  123,   23,  122,  123,   22,  122,  123,
       38,  122,  123,   37,  122,  123,   39,  122,  123,   25,
      122,  123,   76,  112,  122,  123,   76,  112,  122,  123,
       76,  112,  122,  123,   16,  122,  123,  122,  123,   18,
      122,  123,   32,  122,  123,   76,  112,  122,  123,   76,

      112,  122,  123,   76,  112,  122,  123,   76,  112,  122,
      123,   76,  112,  122,  123,   76,  112,  122,  123,   76,
      112,  122,  123,   76,  112,  122,  123,   76,  112,  122,
      123,   76,  112,  122,  123,   76,  112,  122,  123,   76,
      112,  122,  123,   76,  112,  122,  123,   76,  112,  122,
      123,   76,  112,  122,  123,   76,  112,  122,  123,   12,
      122,  123,   34,  122,  123,   14,  122,  123,   35,  122,
      123,    3,    1,   53,  120,   44,   15,   56,   46,  118,
       42,   58,   40,   59,   41,   61,  116,    4,    6,   43,
      116,  114,  115,  115,  115,  115,   19,   13,   17,   48,

       54,   52,   55,   49,   76,  112,   76,  112,    2,   45,
       76,  112,   76,  112,   76,  112,   76,  112,   76,  112,
       76,  112,   76,  112,   76,  112,   76,  112,   76,   85,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
      112,   76,  112,   76,   93,  112,   76,  112,   76,  112,
       76,  112,   76,  112,   76,  112,   76,  112,   76,  112,
       76,  112,   76,  112,   76,  112,   76,  112,   47,   57,
       24,  116,    6,  114,  115,  114,  115,  117,  115,  115,
      115,  113,   50,   51,   76,  112,  121,  119,   76,  112,
       76,  112,   76,  112,   76,  112,   76,  112,   76,  112,

       76,  112,   76,  112,   76,  112,   76,   77,  112,   76,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
      112,   76,   91,  112,   76,  112,   76,  112,   76,   95,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
      112,   76,  112,  116,  114,  115,  114,  115,  114,  115,
      117,  115,  113,  113,   76,  112,   76,  112,   76,  112,
       76,  112,   76,  112,   76,  112,   76,  112,   76,  112,

       76,  112,   76,  112,   76,  112,   76,  112,   76,   78,
      112,   76,  112,   76,   80,  112,   76,   81,  112,   76,
      112,   76,  112,   76,  112,   76,  112,   76,   87,  112,
       76,   88,  112,   76,  112,   76,  112,   76,   92,  112,
       76,  112,   76,   96,  112,   76,  112,   76,  112,   76,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
      109,  112,   76,  112,   76,  112,   10,  114,  115,  113,
      113,  113,   76,  112,   76,  112,   73,   76,  112,   62,
       76,  112,   76,  112,   76,  112,   76,  112,   76,  112,

       76,  112,   76,  112,   76,  112,   76,  112,   76,   79,
      112,   76,   82,  112,   76,  112,   76,  112,   76,  112,
       76,  112,   76,   90,  112,   76,  112,   76,  112,   76,
      112,   76,  112,   76,  100,  112,   76,  112,   76,  112,
       76,  112,   76,  112,   76,  112,   76,  112,   76,  107,
      112,   76,  112,   76,  112,   76,  111,  112,  113,   76,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
      112,   76,  112,   76,  112,   76,   86,  112,   76,   89,
      112,   76,   94,  112,   76,  112,   76,  112,   76,   99,

      112,   76,  101,  112,   76,  102,  112,   76,  103,  112,
       76,  104,  112,   76,  105,  112,   76,  112,   76,  112,
       76,  112,    5,   76,  112,   76,  112,   63,   76,  112,
       76,  112,   66,   76,  112,   76,  112,   76,  112,   76,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
       84,  112,   76,  112,   76,  112,   76,  106,  112,   76,
      112,   76,  112,   76,  112,   76,  112,   76,  112,   76,
      112,   68,   76,  112,   76,  112,   76,  112,   76,  112,
       72,   76,  112,   76,   83,  112,   76,   97,  112,   76,
       98,  112,   76,  108,  112,   76,  110,  112,    8,    9,

       76,  112,   76,  112,   76,  112,   76,  112,   69,   76,
      112,   76,  112,   76,  112,    7,    8,   76,  112,   76,
      112,   76,  112,   76,  112,   71,   76,  112,   70,   76,
      112,   76,  112,   76,  112,   65,   76,  112,   76,  112,
       76,  112,   76,  112,   76,  112,   76,  112,   76,  112,
       76,  112,   64,   76,  112,   67,   76,  112,   76,  112,
       76,  112,   76,  112,   76,  112,   76,  112,   76,  112,
       74,   76,  112,   76,  112,   75,   76,  112
    } ;

static yyconst flex_int16_t yy_accept[409] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   77,
       81,   85,   88,   90,   93,   96,  100,  104,  108,  112,
      116,  120,  124,  128,  132,  136,  140,  144,  148,  152,
      156,  160,  163,  166,  169,  172,  173,  174,  175,  175,
      176,  176,  176,  176,  176,  177,  178,  179,  180,  180,
      181,  181,  182,  183,  184,  185,  186,  187,  187,  188,
      189,  190,  191,  192,  194,  195,  195,  196,  197,  197,
      198,  199,  200,  201,  202,  203,  204,  205,  207,  209,

      209,  209,  210,  211,  213,  215,  217,  219,  221,  223,
      225,  227,  229,  232,  234,  236,  238,  240,  242,  244,
      247,  249,  251,  253,  255,  257,  259,  261,  263,  265,
      267,  269,  270,  271,  271,  271,  271,  272,  272,  273,
      273,  273,  274,  276,  278,  278,  279,  280,  281,  282,
      283,  284,  285,  287,  287,  288,  288,  288,  289,  289,
      291,  293,  295,  297,  299,  301,  303,  305,  307,  310,
      312,  314,  316,  318,  320,  322,  324,  326,  328,  330,
      332,  335,  337,  339,  342,  344,  346,  348,  350,  352,
      354,  356,  358,  360,  362,  364,  366,  368,  370,  372,

      374,  374,  374,  374,  374,  375,  375,  377,  379,  381,
      382,  383,  384,  385,  387,  389,  391,  393,  395,  397,
      399,  401,  403,  405,  407,  409,  412,  414,  417,  420,
      422,  424,  426,  428,  431,  434,  436,  438,  441,  443,
      446,  448,  450,  452,  454,  456,  458,  460,  462,  464,
      466,  468,  470,  473,  475,  477,  477,  478,  478,  478,
      478,  480,  481,  482,  483,  485,  487,  490,  493,  495,
      497,  499,  501,  503,  505,  507,  509,  512,  515,  517,
      519,  521,  523,  526,  528,  530,  532,  534,  537,  539,
      541,  543,  545,  547,  549,  552,  554,  556,  559,  559,

      559,  559,  559,  560,  562,  564,  566,  568,  570,  572,
      574,  576,  578,  580,  582,  584,  586,  589,  592,  595,
      597,  599,  602,  605,  608,  611,  614,  617,  619,  621,
      623,  623,  623,  624,  626,  628,  631,  633,  636,  638,
      640,  642,  644,  646,  648,  650,  653,  655,  657,  660,
      662,  664,  664,  664,  666,  668,  670,  672,  675,  677,
      679,  681,  684,  687,  690,  693,  696,  699,  700,  700,
      701,  703,  705,  707,  709,  712,  714,  716,  717,  718,
      720,  722,  724,  726,  729,  732,  734,  736,  739,  741,
      743,  745,  747,  749,  751,  753,  756,  759,  761,  763,

      765,  767,  769,  771,  774,  776,  779,  779
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   21,
       21,   22,   21,   23,   21,   24,   24,   25,   26,   27,
       28,   29,   30,    1,   31,   32,   33,   34,   35,   36,
       37,   38,   39,   38,   38,   40,   38,   41,   42,   38,
       38,   38,   43,   44,   45,   38,   38,   46,   38,   38,
       47,   48,   49,   50,   51,    1,   52,   53,   54,   55,

       56,   57,   58,   59,   60,   38,   61,   62,   63,   64,
       65,   66,   38,   67,   68,   69,   70,   71,   72,   73,
       74,   75,   76,   77,   78,   79,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[80] =
    {   0,
        1,    2,    3,    1,    2,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    2,    1,    1,    1,    5,
        5,    5,    5,    5,    1,    1,    1,    2,    1,    1,
        6,    6,    6,    6,    6,    6,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    1,    1,    1,    1,
        7,    6,    6,    6,    6,    6,    6,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[421] =
    {   0,
        0,    0,  618,  619,   78,    0,  589,   74,   79,   57,
       77,   77,  619,  619,  588,   74,  619,   75,   73,   87,
      128,   87,  586,  619,   89,  586,   71,  619,    0,  562,
      112,  619,  609,  619,  583,   79,   50,  543,   72,   56,
       65,   70,  544,   79,  543,  551,   95,  532,  541,  539,
      544,  619,   62,  619,  619,  154,    0,  619,  121,  619,
      599,  155,  545,  533,  619,  619,  619,  619,  133,  619,
      596,  619,  619,  619,  619,  619,  619,  580,  171,  160,
        0,  619,  194,  126,    0,  220,  140,  121,    0,  619,
      619,  619,  569,  619,  619,  619,  568,    0,  558,  134,

      175,  619,  619,  529,  193,  530,  523,  535,  522,  537,
      524,  530,  516,  517,  514,  514,  517,  514,  511,    0,
       78,  515,  151,  513,   95,   90,  517,  510,  129,  143,
      515,  619,  619,  243,  517,  521,  619,  253,  619,  545,
        0,    0,  238,  160,  264,  269,  168,  619,  164,  254,
      619,  619,  186,  232,  619,  568,  210,  619,  567,  504,
      186,  503,  494,  502,  500,  508,  503,  488,    0,  496,
      508,  503,  491,  203,  505,  503,  499,  491,  497,  500,
        0,  486,  490,    0,  491,  488,  478,  476,  478,  480,
      487,  473,  471,  471,  483,  473,  477,  481,  483,  472,

      530,  472,  473,  290,  297,  501,  234,  619,  184,  619,
      619,  282,  219,  488,  489,  465,  463,  456,  460,  454,
      460,  457,  452,  461,  452,    0,  456,    0,    0,  447,
      455,  444,  451,    0,    0,  445,  442,    0,  446,    0,
      441,  441,  440,  437,  449,  439,  443,  448,  447,  445,
      435,  440,    0,  428,  440,  492,  619,  430,  430,  293,
      619,  258,  619,  261,  448,  450,    0,  439,  422,  420,
      431,  426,  421,  415,  419,  426,    0,    0,  417,  418,
      423,  414,    0,  421,  407,  415,  410,    0,  418,  415,
      417,  401,  410,  412,    0,  403,  406,    0,  409,  412,

      449,  443,  619,  438,  416,  408,  398,  388,  392,  391,
      384,  386,  396,  386,  380,  380,    0,    0,    0,  392,
      393,    0,    0,    0,    0,    0,    0,  389,  389,  382,
      438,  437,  619,  419,  417,    0,  386,    0,  370,  381,
      374,  375,  379,  376,  353,    0,  341,  317,    0,  307,
      302,    0,  354,  305,  333,  283,  291,    0,  288,  295,
      297,    0,    0,    0,    0,    0,    0,  335,  343,  619,
      312,  292,  273,  276,    0,  271,  288,  619,  326,  294,
      302,  278,  268,    0,    0,  289,  287,  274,  264,  263,
      261,  246,  245,  238,  226,    0,    0,  221,  192,  191,

      181,  164,   85,    0,   69,    0,  619,  359,  366,  373,
      376,  383,  386,  392,  399,  405,  412,  414,  421,  425
    } ;

static yyconst flex_int16_t yy_def[421] =
    {   0,
      407,    1,  407,  407,  407,  408,  407,  409,  407,  407,
      407,  410,  407,  407,  407,  407,  407,  407,  407,  407,
      407,   21,  407,  407,  407,  407,  407,  407,  411,  411,
      411,  407,  407,  407,  407,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  407,  407,  407,  407,  407,  408,  407,  409,  407,
      409,  407,  407,  407,  407,  407,  407,  407,  410,  407,
      410,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      412,  407,  407,   21,   22,  407,  407,  407,  413,  407,
      407,  407,  407,  407,  407,  407,  407,  411,  411,  414,

      415,  407,  407,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      416,  412,  407,  407,  407,  407,  407,  407,  407,  413,
      407,  407,  411,  414,  407,  414,  415,  407,  415,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,

      417,  407,  407,  407,  407,  416,  407,  407,  407,  407,
      407,  407,  407,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  417,  407,  407,  407,  407,
      407,  407,  407,  407,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  407,  407,

      407,  407,  407,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      407,  407,  407,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  418,  419,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  420,  419,  407,
      411,  411,  411,  411,  411,  411,  411,  407,  420,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,

      411,  411,  411,  411,  411,  411,    0,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407
    } ;

static yyconst flex_int16_t yy_nxt[699] =
    {   0,
        4,    5,    6,    5,    5,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   23,   24,   25,   26,   27,   28,
       29,   29,   29,   29,   29,   29,   30,   29,   29,   31,
       29,   29,   29,   29,   29,   29,   32,   33,   34,   35,
       36,   37,   38,   39,   40,   41,   42,   43,   29,   44,
       29,   45,   29,   29,   29,   29,   46,   47,   48,   49,
       50,   51,   29,   29,   29,   52,   53,   54,   55,   56,
       60,   56,   56,   62,   65,   66,   67,   70,   73,  132,
       78,   75,   79,   79,   79,   79,   79,   91,   96,   97,

       80,   74,   76,   77,   68,   81,   85,   85,   85,   85,
      104,  112,  406,   92,   82,   93,   94,  106,  100,  107,
      113,   61,  101,  109,   71,  405,  114,   60,  115,  105,
      110,  117,  407,   63,  118,  120,  111,  116,  133,  183,
      155,  192,  121,   70,   64,   83,  184,   84,   84,   84,
       84,   85,  190,  124,  125,   56,  193,   56,   56,  407,
      149,  140,   86,  126,  140,  143,  127,   87,   61,  191,
      144,  407,   88,   89,  134,  134,  134,  134,  134,  147,
       71,  156,  149,   86,  148,  158,  141,  143,  196,   87,
       79,   79,   79,   79,   79,  144,  197,   88,  407,  209,

       89,  147,  198,  211,  199,  138,  139,  404,  186,  148,
      139,  403,  148,   79,   79,   79,   79,   79,  187,  188,
      158,  209,  159,  261,  214,  211,  138,  139,  138,  139,
      215,  402,  139,  139,  145,  401,  145,  148,  155,  146,
      146,  146,  146,  146,  161,  261,  162,  201,  163,  138,
      139,  400,  164,  217,  218,  139,  165,  159,  264,  166,
      167,  168,  134,  134,  134,  134,  134,  204,  399,  204,
      230,  231,  205,  205,  205,  205,  205,  207,  208,  156,
      264,  398,  208,  146,  146,  146,  146,  146,  146,  146,
      146,  146,  146,  212,  301,  397,  396,  301,  213,  207,

      303,  395,  263,  208,  210,  394,  302,  208,  210,  205,
      205,  205,  205,  205,  393,  212,  205,  205,  205,  205,
      205,  262,  303,  213,  392,  210,  263,  263,  391,  390,
      210,  389,  139,  388,  387,  386,  139,  378,  385,  384,
      383,  382,  381,  262,  380,  370,  378,  377,  376,  375,
      374,  263,  373,  139,  372,  371,  370,  367,  139,   57,
       57,  366,   57,   57,   57,   57,   59,   59,   59,   59,
       59,   59,   59,   69,   69,   69,   69,   69,   69,   69,
       98,   98,   98,  142,  142,  365,  142,  142,  142,  142,
      150,  150,  154,  154,  154,  154,  154,  154,  154,  157,

      157,  157,  157,  157,  157,  157,  206,  364,  363,  206,
      206,  206,  256,  256,  256,  256,  256,  256,  256,  368,
      368,  369,  369,  369,  369,  369,  369,  369,  379,  379,
      379,  379,  362,  361,  360,  359,  358,  357,  356,  355,
      354,  353,  352,  351,  350,  349,  348,  347,  346,  345,
      344,  343,  342,  341,  340,  339,  338,  337,  336,  335,
      334,  333,  302,  332,  331,  330,  329,  328,  327,  326,
      325,  324,  323,  322,  321,  320,  319,  318,  317,  316,
      315,  314,  313,  312,  311,  310,  309,  308,  307,  306,
      305,  304,  300,  299,  257,  298,  297,  296,  295,  294,

      293,  292,  291,  290,  289,  288,  287,  286,  285,  284,
      283,  282,  281,  280,  279,  278,  277,  276,  275,  274,
      273,  272,  271,  270,  269,  268,  267,  266,  265,  260,
      259,  258,  257,  255,  254,  253,  252,  251,  250,  249,
      248,  247,  246,  245,  244,  243,  242,  241,  240,  239,
      238,  237,  236,  235,  234,  233,  232,  229,  228,  227,
      226,  225,  224,  223,  222,  221,  220,  219,  216,  407,
      407,  141,  203,  202,  200,  195,  194,  189,  185,  182,
      181,  180,  179,  178,  177,  176,  175,  174,  173,  172,
      171,  170,  169,  160,  153,  152,  151,  137,  407,  136,

      135,  407,  131,  130,  129,  128,  123,  122,  119,  108,
      103,  102,   99,   95,   90,   72,   58,  407,    3,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407

    } ;

static yyconst flex_int16_t yy_chk[699] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    5,
        8,    5,    5,    9,   10,   10,   11,   12,   16,   53,
       19,   18,   19,   19,   19,   19,   19,   25,   27,   27,

       20,   16,   18,   18,   11,   20,   22,   22,   22,   22,
       36,   40,  405,   25,   20,   25,   25,   37,   31,   37,
       40,    8,   31,   39,   12,  403,   41,   59,   41,   36,
       39,   42,   22,    9,   42,   44,   39,   41,   53,  121,
      100,  126,   44,   69,    9,   21,  121,   21,   21,   21,
       21,   21,  125,   47,   47,   56,  126,   56,   56,   22,
       88,   80,   21,   47,   80,   84,   47,   21,   59,  125,
       84,   84,   21,   21,   62,   62,   62,   62,   62,   87,
       69,  100,   88,   21,   87,  101,   80,   84,  129,   21,
       79,   79,   79,   79,   79,   84,  129,   21,   84,  144,

       21,   87,  130,  149,  130,   79,   79,  402,  123,   87,
       79,  401,  147,   83,   83,   83,   83,   83,  123,  123,
      157,  144,  101,  209,  153,  149,   79,   79,   83,   83,
      153,  400,   79,   83,   86,  399,   86,  147,  154,   86,
       86,   86,   86,   86,  105,  209,  105,  134,  105,   83,
       83,  398,  105,  161,  161,   83,  105,  157,  213,  105,
      105,  105,  134,  134,  134,  134,  134,  138,  395,  138,
      174,  174,  138,  138,  138,  138,  138,  143,  207,  154,
      213,  394,  143,  145,  145,  145,  145,  145,  146,  146,
      146,  146,  146,  150,  260,  393,  392,  260,  150,  143,

      264,  391,  262,  207,  146,  390,  260,  143,  146,  204,
      204,  204,  204,  204,  389,  150,  205,  205,  205,  205,
      205,  212,  264,  150,  388,  146,  212,  262,  387,  386,
      146,  383,  205,  382,  381,  380,  205,  379,  377,  376,
      374,  373,  372,  212,  371,  369,  368,  361,  360,  359,
      357,  212,  356,  205,  355,  354,  353,  351,  205,  408,
      408,  350,  408,  408,  408,  408,  409,  409,  409,  409,
      409,  409,  409,  410,  410,  410,  410,  410,  410,  410,
      411,  411,  411,  412,  412,  348,  412,  412,  412,  412,
      413,  413,  414,  414,  414,  414,  414,  414,  414,  415,

      415,  415,  415,  415,  415,  415,  416,  347,  345,  416,
      416,  416,  417,  417,  417,  417,  417,  417,  417,  418,
      418,  419,  419,  419,  419,  419,  419,  419,  420,  420,
      420,  420,  344,  343,  342,  341,  340,  339,  337,  335,
      334,  332,  331,  330,  329,  328,  321,  320,  316,  315,
      314,  313,  312,  311,  310,  309,  308,  307,  306,  305,
      304,  302,  301,  300,  299,  297,  296,  294,  293,  292,
      291,  290,  289,  287,  286,  285,  284,  282,  281,  280,
      279,  276,  275,  274,  273,  272,  271,  270,  269,  268,
      266,  265,  259,  258,  256,  255,  254,  252,  251,  250,

      249,  248,  247,  246,  245,  244,  243,  242,  241,  239,
      237,  236,  233,  232,  231,  230,  227,  225,  224,  223,
      222,  221,  220,  219,  218,  217,  216,  215,  214,  206,
      203,  202,  201,  200,  199,  198,  197,  196,  195,  194,
      193,  192,  191,  190,  189,  188,  187,  186,  185,  183,
      182,  180,  179,  178,  177,  176,  175,  173,  172,  171,
      170,  168,  167,  166,  165,  164,  163,  162,  160,  159,
      156,  140,  136,  135,  131,  128,  127,  124,  122,  119,
      118,  117,  116,  115,  114,  113,  112,  111,  110,  109,
      108,  107,  106,  104,   99,   97,   93,   78,   71,   64,

       63,   61,   51,   50,   49,   48,   46,   45,   43,   38,
       35,   33,   30,   26,   23,   15,    7,    3,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407

    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "giscanner/scannerlexer.l"
/* -*- Mode: C -*-
 * GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 * Copyright (c) 2010 Andreas Rottmann <a.rottmann@gmx.at>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 32 "giscanner/scannerlexer.l"
#include <ctype.h>
#include <stdio.h>

#include <glib.h>
#include "sourcescanner.h"
#include "scannerparser.h"
#include "grealpath.h"

int lineno;
char linebuf[2000];

#undef YY_BUF_SIZE
#define YY_BUF_SIZE 1048576

extern int yylex (GISourceScanner *scanner);
#define YY_DECL int yylex (GISourceScanner *scanner)
static int yywrap (void);
static void parse_comment (GISourceScanner *scanner);
static void parse_trigraph (GISourceScanner *scanner);
static void process_linemarks (GISourceScanner *scanner);
static int check_identifier (GISourceScanner *scanner, const char *);
static int parse_ignored_macro (void);
#line 888 "scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 65 "giscanner/scannerlexer.l"


#line 1071 "scannerlexer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 408 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 619 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 67 "giscanner/scannerlexer.l"
{ strncpy(linebuf, yytext+1, sizeof(linebuf)); /* save the next line */
						linebuf[sizeof(linebuf)-1]='\0';
						/* printf("%4d:%s\n",lineno,linebuf); */
						yyless(1);      /* give back all but the \n to rescan */
						++lineno;
					}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 73 "giscanner/scannerlexer.l"
{ ++lineno; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 74 "giscanner/scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 76 "giscanner/scannerlexer.l"
{ parse_comment(scanner); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 77 "giscanner/scannerlexer.l"
{ parse_trigraph(scanner); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 78 "giscanner/scannerlexer.l"
{ /* Ignore C++ style comments. */ }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 80 "giscanner/scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 81 "giscanner/scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 82 "giscanner/scannerlexer.l"
{ /* Ignore pragma. */ }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 84 "giscanner/scannerlexer.l"
{ process_linemarks(scanner); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 85 "giscanner/scannerlexer.l"
{ }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 86 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 87 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 88 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 89 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 90 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 91 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 92 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 93 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 94 "giscanner/scannerlexer.l"
{ return '('; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 95 "giscanner/scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 96 "giscanner/scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 97 "giscanner/scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 98 "giscanner/scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 99 "giscanner/scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 100 "giscanner/scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 101 "giscanner/scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 102 "giscanner/scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 103 "giscanner/scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 104 "giscanner/scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 105 "giscanner/scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 106 "giscanner/scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 107 "giscanner/scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 108 "giscanner/scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 109 "giscanner/scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 110 "giscanner/scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 111 "giscanner/scannerlexer.l"
{ return '='; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 112 "giscanner/scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 113 "giscanner/scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 114 "giscanner/scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 115 "giscanner/scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 116 "giscanner/scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 117 "giscanner/scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 118 "giscanner/scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 119 "giscanner/scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 120 "giscanner/scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 121 "giscanner/scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 122 "giscanner/scannerlexer.l"
{ return SL; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 123 "giscanner/scannerlexer.l"
{ return SR; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 124 "giscanner/scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 125 "giscanner/scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 126 "giscanner/scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 127 "giscanner/scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 128 "giscanner/scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 129 "giscanner/scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 130 "giscanner/scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 131 "giscanner/scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 132 "giscanner/scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 133 "giscanner/scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 134 "giscanner/scannerlexer.l"
{ return ','; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 135 "giscanner/scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 137 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 138 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 139 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 140 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 141 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 142 "giscanner/scannerlexer.l"
{ return EXTENSION; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 143 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 144 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 145 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 146 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 147 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 148 "giscanner/scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 150 "giscanner/scannerlexer.l"
{ return INTL_CONST; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 151 "giscanner/scannerlexer.l"
{ return INTUL_CONST; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 152 "giscanner/scannerlexer.l"
{ if (scanner->macro_scan) return check_identifier(scanner, yytext); else REJECT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 154 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 155 "giscanner/scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 156 "giscanner/scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 157 "giscanner/scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 158 "giscanner/scannerlexer.l"
{ return CHAR; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 159 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 160 "giscanner/scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 161 "giscanner/scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 162 "giscanner/scannerlexer.l"
{ return DO; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 163 "giscanner/scannerlexer.l"
{ return DOUBLE; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 164 "giscanner/scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 165 "giscanner/scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 166 "giscanner/scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 167 "giscanner/scannerlexer.l"
{ return FLOAT; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 168 "giscanner/scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 169 "giscanner/scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 170 "giscanner/scannerlexer.l"
{ return IF; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 171 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 172 "giscanner/scannerlexer.l"
{ return INT; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 173 "giscanner/scannerlexer.l"
{ return LONG; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 174 "giscanner/scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 175 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 176 "giscanner/scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 177 "giscanner/scannerlexer.l"
{ return SHORT; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 178 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 179 "giscanner/scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 180 "giscanner/scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 181 "giscanner/scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 182 "giscanner/scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 183 "giscanner/scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 184 "giscanner/scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 185 "giscanner/scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 186 "giscanner/scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 187 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 188 "giscanner/scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 190 "giscanner/scannerlexer.l"
{ return check_identifier(scanner, yytext); }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 192 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 193 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 194 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 196 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 197 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 118:
/* rule 118 can match eol */
YY_RULE_SETUP
#line 199 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 119:
/* rule 119 can match eol */
YY_RULE_SETUP
#line 200 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 120:
/* rule 120 can match eol */
YY_RULE_SETUP
#line 202 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 121:
/* rule 121 can match eol */
YY_RULE_SETUP
#line 203 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 205 "giscanner/scannerlexer.l"
{ if (yytext[0]) fprintf(stderr, "%s:%d: unexpected character `%c'\n", scanner->current_filename, lineno, yytext[0]); }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 207 "giscanner/scannerlexer.l"
ECHO;
	YY_BREAK
#line 1791 "scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 408 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 408 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 407);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 207 "giscanner/scannerlexer.l"



static int
yywrap (void)
{
  return 1;
}


static void
parse_comment (GISourceScanner *scanner)
{
  GString *string = NULL;
  int c1, c2;
  GISourceComment *comment;
  int comment_lineno;
  int skip = FALSE;

  if (!g_list_find_custom (scanner->filenames,
                           scanner->current_filename,
                           (GCompareFunc)g_strcmp0)) {
      skip = TRUE;
  } else {
      string = g_string_new ("/*");
  }

  c1 = input();
  c2 = input();

  comment_lineno = lineno;

  while (c2 != EOF && !(c1 == '*' && c2 == '/'))
    {
      if (!skip)
        g_string_append_c (string, c1);

      if (c1 == '\n')
        lineno++;

      c1 = c2;
      c2 = input();
    }

  if (skip) {
      return;
  }

  g_string_append (string, "*/");

  comment = g_slice_new (GISourceComment);
  comment->comment = g_string_free (string, FALSE);
  comment->line = comment_lineno;
  comment->filename = g_strdup(scanner->current_filename);

  scanner->comments = g_slist_prepend (scanner->comments,
                                       comment);
}

static int
check_identifier (GISourceScanner *scanner,
		  const char  *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (gi_source_scanner_is_typedef (scanner, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

/*
 * # linenum "filename" flags
 *  See http://gcc.gnu.org/onlinedocs/cpp/Preprocessor-Output.html
 **/

static void
process_linemarks (GISourceScanner *scanner)
{
        char filename[1025];
        char *compress;
        char *real;

        sscanf(yytext, "# %d \"%1024[^\"]\"", &lineno, filename);

	compress = g_strcompress (filename);
        real = g_realpath (filename);
        if (real) {
                g_free (scanner->current_filename);
                scanner->current_filename = real;
        } else {
                g_free (real);
        }
        g_free (compress);
}

/*
 * This parses a macro which is ignored, such as
 * __attribute__((x)) or __asm__ (x)
 */
static int
parse_ignored_macro (void)
{
	int c;
	int nest;

	while ((c = input ()) != EOF && isspace (c))
		;
	if (c != '(')
		return FALSE;

	nest = 0;
	while ((c = input ()) != EOF && (nest > 0 || c != ')')) {
		if (c == '(')
			nest++;
		else if (c == ')')
			nest--;
		else if (c == '"') {
			while ((c = input ()) != EOF && c != '"') {
				if (c == '\\')
					c = input ();
			}
		} else if (c == '\'') {
			c = input ();
			if (c == '\\')
				c = input ();
			else if (c == '\'')
				return FALSE;
			c = input ();
			if (c != '\'')
				return FALSE;
		} else if (c == '\n')
			lineno++;
	}

	return TRUE;
}

static void
parse_trigraph (GISourceScanner *scanner)
{
	char **items;
	char *start, *end;
	int i;

	start = g_strstr_len (yytext, yyleng, "<");
	g_assert (start != NULL);
	end = g_strstr_len (yytext, yyleng, ">");
	g_assert (end != NULL);
	*end = '\0';
	items = g_strsplit (start + 1, ",", 0);
	for (i = 0; items[i] != NULL; i++) {
		char *item = items[i];
		g_strstrip (item);
		if (strcmp (item, "public") == 0)
			scanner->private = FALSE;
		else if (strcmp (item, "private") == 0)
			scanner->private = TRUE;
		else if (strcmp (item, "flags") == 0)
			scanner->flags = TRUE;
	}
	g_strfreev (items);
}

